| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.PinpointSmsVoiceV2.Types.KeywordFilter
Description
Documentation
data KeywordFilter Source #
The information for keywords that meet a specified criteria.
See: newKeywordFilter smart constructor.
Constructors
| KeywordFilter' | |
Fields
| |
Instances
Arguments
| :: KeywordFilterName | |
| -> NonEmpty Text | |
| -> KeywordFilter |
Create a value of KeywordFilter with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:name:KeywordFilter', keywordFilter_name - The name of the attribute to filter on.
$sel:values:KeywordFilter', keywordFilter_values - An array values to filter for.
keywordFilter_name :: Lens' KeywordFilter KeywordFilterName Source #
The name of the attribute to filter on.
keywordFilter_values :: Lens' KeywordFilter (NonEmpty Text) Source #
An array values to filter for.